//! This file has been automatically generated by `objc2`'s `header-translator`.
//! DO NOT EDIT
use core::ptr::NonNull;
use objc2::__framework_prelude::*;
use objc2_foundation::*;

use crate::*;

mod private_NSStringUNUserNotificationCenterSupport {
    pub trait Sealed {}
}

/// Category "UNUserNotificationCenterSupport" on [`NSString`].
#[doc(alias = "UNUserNotificationCenterSupport")]
pub unsafe trait NSStringUNUserNotificationCenterSupport:
    ClassType + Sized + private_NSStringUNUserNotificationCenterSupport::Sealed
{
    extern_methods!(
        /// # Safety
        ///
        /// `arguments` generic should be of the correct type.
        #[unsafe(method(localizedUserNotificationStringForKey:arguments:))]
        #[unsafe(method_family = none)]
        unsafe fn localizedUserNotificationStringForKey_arguments(
            key: &NSString,
            arguments: Option<&NSArray>,
        ) -> Retained<NSString>;
    );
}

impl private_NSStringUNUserNotificationCenterSupport::Sealed for NSString {}
unsafe impl NSStringUNUserNotificationCenterSupport for NSString {}
