// This file has been automatically generated by `objc2`'s `header-translator`.
// DO NOT EDIT

#![allow(unused_imports)]
#![allow(deprecated)]
#![allow(non_snake_case)]
#![allow(non_camel_case_types)]
#![allow(non_upper_case_globals)]
#![allow(missing_docs)]
#![allow(clippy::too_many_arguments)]
#![allow(clippy::type_complexity)]
#![allow(clippy::upper_case_acronyms)]
#![allow(clippy::identity_op)]
#![allow(clippy::missing_safety_doc)]
#![allow(clippy::doc_lazy_continuation)]
#![allow(rustdoc::broken_intra_doc_links)]
#![allow(rustdoc::bare_urls)]
#![allow(rustdoc::invalid_html_tags)]

#[link(name = "UserNotifications", kind = "framework")]
extern "C" {}

#[cfg(feature = "NSString_UserNotifications")]
#[path = "NSString_UserNotifications.rs"]
mod __NSString_UserNotifications;
#[cfg(feature = "UNError")]
#[path = "UNError.rs"]
mod __UNError;
#[cfg(feature = "UNNotification")]
#[path = "UNNotification.rs"]
mod __UNNotification;
#[cfg(feature = "UNNotificationAction")]
#[path = "UNNotificationAction.rs"]
mod __UNNotificationAction;
#[cfg(feature = "UNNotificationActionIcon")]
#[path = "UNNotificationActionIcon.rs"]
mod __UNNotificationActionIcon;
#[cfg(feature = "UNNotificationAttachment")]
#[path = "UNNotificationAttachment.rs"]
mod __UNNotificationAttachment;
#[cfg(feature = "UNNotificationAttributedMessageContext")]
#[path = "UNNotificationAttributedMessageContext.rs"]
mod __UNNotificationAttributedMessageContext;
#[cfg(feature = "UNNotificationCategory")]
#[path = "UNNotificationCategory.rs"]
mod __UNNotificationCategory;
#[cfg(feature = "UNNotificationContent")]
#[path = "UNNotificationContent.rs"]
mod __UNNotificationContent;
#[cfg(feature = "UNNotificationRequest")]
#[path = "UNNotificationRequest.rs"]
mod __UNNotificationRequest;
#[cfg(feature = "UNNotificationResponse")]
#[path = "UNNotificationResponse.rs"]
mod __UNNotificationResponse;
#[cfg(feature = "UNNotificationServiceExtension")]
#[path = "UNNotificationServiceExtension.rs"]
mod __UNNotificationServiceExtension;
#[cfg(feature = "UNNotificationSettings")]
#[path = "UNNotificationSettings.rs"]
mod __UNNotificationSettings;
#[cfg(feature = "UNNotificationSound")]
#[path = "UNNotificationSound.rs"]
mod __UNNotificationSound;
#[cfg(feature = "UNNotificationTrigger")]
#[path = "UNNotificationTrigger.rs"]
mod __UNNotificationTrigger;
#[cfg(feature = "UNUserNotificationCenter")]
#[path = "UNUserNotificationCenter.rs"]
mod __UNUserNotificationCenter;

#[cfg(feature = "NSString_UserNotifications")]
pub use self::__NSString_UserNotifications::NSStringUNUserNotificationCenterSupport;
#[cfg(feature = "UNError")]
pub use self::__UNError::UNErrorCode;
#[cfg(feature = "UNError")]
pub use self::__UNError::UNErrorDomain;
#[cfg(feature = "UNNotification")]
pub use self::__UNNotification::UNNotification;
#[cfg(feature = "UNNotificationAction")]
pub use self::__UNNotificationAction::UNNotificationAction;
#[cfg(feature = "UNNotificationAction")]
pub use self::__UNNotificationAction::UNNotificationActionOptionNone;
#[cfg(feature = "UNNotificationAction")]
pub use self::__UNNotificationAction::UNNotificationActionOptions;
#[cfg(feature = "UNNotificationAction")]
pub use self::__UNNotificationAction::UNTextInputNotificationAction;
#[cfg(feature = "UNNotificationActionIcon")]
pub use self::__UNNotificationActionIcon::UNNotificationActionIcon;
#[cfg(feature = "UNNotificationAttachment")]
pub use self::__UNNotificationAttachment::UNNotificationAttachment;
#[cfg(feature = "UNNotificationAttachment")]
pub use self::__UNNotificationAttachment::UNNotificationAttachmentOptionsThumbnailClippingRectKey;
#[cfg(feature = "UNNotificationAttachment")]
pub use self::__UNNotificationAttachment::UNNotificationAttachmentOptionsThumbnailHiddenKey;
#[cfg(feature = "UNNotificationAttachment")]
pub use self::__UNNotificationAttachment::UNNotificationAttachmentOptionsThumbnailTimeKey;
#[cfg(feature = "UNNotificationAttachment")]
pub use self::__UNNotificationAttachment::UNNotificationAttachmentOptionsTypeHintKey;
#[cfg(feature = "UNNotificationAttributedMessageContext")]
pub use self::__UNNotificationAttributedMessageContext::UNNotificationAttributedMessageContext;
#[cfg(feature = "UNNotificationCategory")]
pub use self::__UNNotificationCategory::UNNotificationCategory;
#[cfg(feature = "UNNotificationCategory")]
pub use self::__UNNotificationCategory::UNNotificationCategoryOptionNone;
#[cfg(feature = "UNNotificationCategory")]
pub use self::__UNNotificationCategory::UNNotificationCategoryOptions;
#[cfg(feature = "UNNotificationContent")]
pub use self::__UNNotificationContent::UNMutableNotificationContent;
#[cfg(feature = "UNNotificationContent")]
pub use self::__UNNotificationContent::UNNotificationContent;
#[cfg(feature = "UNNotificationContent")]
pub use self::__UNNotificationContent::UNNotificationContentProviding;
#[cfg(feature = "UNNotificationContent")]
pub use self::__UNNotificationContent::UNNotificationInterruptionLevel;
#[cfg(feature = "UNNotificationRequest")]
pub use self::__UNNotificationRequest::UNNotificationRequest;
#[cfg(feature = "UNNotificationResponse")]
pub use self::__UNNotificationResponse::UNNotificationDefaultActionIdentifier;
#[cfg(feature = "UNNotificationResponse")]
pub use self::__UNNotificationResponse::UNNotificationDismissActionIdentifier;
#[cfg(feature = "UNNotificationResponse")]
pub use self::__UNNotificationResponse::UNNotificationResponse;
#[cfg(feature = "UNNotificationResponse")]
pub use self::__UNNotificationResponse::UNTextInputNotificationResponse;
#[cfg(feature = "UNNotificationServiceExtension")]
pub use self::__UNNotificationServiceExtension::UNNotificationServiceExtension;
#[cfg(feature = "UNNotificationSettings")]
pub use self::__UNNotificationSettings::UNAlertStyle;
#[cfg(feature = "UNNotificationSettings")]
pub use self::__UNNotificationSettings::UNAuthorizationStatus;
#[cfg(feature = "UNNotificationSettings")]
pub use self::__UNNotificationSettings::UNNotificationSetting;
#[cfg(feature = "UNNotificationSettings")]
pub use self::__UNNotificationSettings::UNNotificationSettings;
#[cfg(feature = "UNNotificationSettings")]
pub use self::__UNNotificationSettings::UNShowPreviewsSetting;
#[cfg(feature = "UNNotificationSound")]
pub use self::__UNNotificationSound::UNNotificationSound;
#[cfg(feature = "UNNotificationSound")]
pub use self::__UNNotificationSound::UNNotificationSoundName;
#[cfg(feature = "UNNotificationTrigger")]
pub use self::__UNNotificationTrigger::UNCalendarNotificationTrigger;
#[cfg(feature = "UNNotificationTrigger")]
pub use self::__UNNotificationTrigger::UNLocationNotificationTrigger;
#[cfg(feature = "UNNotificationTrigger")]
pub use self::__UNNotificationTrigger::UNNotificationTrigger;
#[cfg(feature = "UNNotificationTrigger")]
pub use self::__UNNotificationTrigger::UNPushNotificationTrigger;
#[cfg(feature = "UNNotificationTrigger")]
pub use self::__UNNotificationTrigger::UNTimeIntervalNotificationTrigger;
#[cfg(feature = "UNUserNotificationCenter")]
pub use self::__UNUserNotificationCenter::UNAuthorizationOptionNone;
#[cfg(feature = "UNUserNotificationCenter")]
pub use self::__UNUserNotificationCenter::UNAuthorizationOptions;
#[cfg(feature = "UNUserNotificationCenter")]
pub use self::__UNUserNotificationCenter::UNNotificationPresentationOptionNone;
#[cfg(feature = "UNUserNotificationCenter")]
pub use self::__UNUserNotificationCenter::UNNotificationPresentationOptions;
#[cfg(feature = "UNUserNotificationCenter")]
pub use self::__UNUserNotificationCenter::UNUserNotificationCenter;
#[cfg(feature = "UNUserNotificationCenter")]
pub use self::__UNUserNotificationCenter::UNUserNotificationCenterDelegate;
