//! This file has been automatically generated by `objc2`'s `header-translator`.
//! DO NOT EDIT
use core::ptr::NonNull;
use objc2::__framework_prelude::*;
use objc2_foundation::*;

use crate::*;

extern_class!(
    /// [Apple's documentation](https://developer.apple.com/documentation/usernotifications/unnotification?language=objc)
    #[unsafe(super(NSObject))]
    #[derive(Debug, PartialEq, Eq, Hash)]
    pub struct UNNotification;
);

extern_conformance!(
    unsafe impl NSCoding for UNNotification {}
);

extern_conformance!(
    unsafe impl NSCopying for UNNotification {}
);

unsafe impl CopyingHelper for UNNotification {
    type Result = Self;
}

extern_conformance!(
    unsafe impl NSObjectProtocol for UNNotification {}
);

extern_conformance!(
    unsafe impl NSSecureCoding for UNNotification {}
);

impl UNNotification {
    extern_methods!(
        #[unsafe(method(date))]
        #[unsafe(method_family = none)]
        pub fn date(&self) -> Retained<NSDate>;

        #[cfg(feature = "UNNotificationRequest")]
        #[unsafe(method(request))]
        #[unsafe(method_family = none)]
        pub fn request(&self) -> Retained<UNNotificationRequest>;

        #[unsafe(method(init))]
        #[unsafe(method_family = init)]
        pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>;
    );
}

/// Methods declared on superclass `NSObject`.
impl UNNotification {
    extern_methods!(
        #[unsafe(method(new))]
        #[unsafe(method_family = new)]
        pub unsafe fn new() -> Retained<Self>;
    );
}
