//! This file has been automatically generated by `objc2`'s `header-translator`.
//! DO NOT EDIT
use core::ptr::NonNull;
use objc2::__framework_prelude::*;
use objc2_foundation::*;

use crate::*;

extern_class!(
    /// [Apple's documentation](https://developer.apple.com/documentation/usernotifications/unnotificationactionicon?language=objc)
    #[unsafe(super(NSObject))]
    #[derive(Debug, PartialEq, Eq, Hash)]
    pub struct UNNotificationActionIcon;
);

extern_conformance!(
    unsafe impl NSCoding for UNNotificationActionIcon {}
);

extern_conformance!(
    unsafe impl NSCopying for UNNotificationActionIcon {}
);

unsafe impl CopyingHelper for UNNotificationActionIcon {
    type Result = Self;
}

extern_conformance!(
    unsafe impl NSObjectProtocol for UNNotificationActionIcon {}
);

extern_conformance!(
    unsafe impl NSSecureCoding for UNNotificationActionIcon {}
);

impl UNNotificationActionIcon {
    extern_methods!(
        #[unsafe(method(iconWithTemplateImageName:))]
        #[unsafe(method_family = none)]
        pub fn iconWithTemplateImageName(template_image_name: &NSString) -> Retained<Self>;

        #[unsafe(method(iconWithSystemImageName:))]
        #[unsafe(method_family = none)]
        pub fn iconWithSystemImageName(system_image_name: &NSString) -> Retained<Self>;

        #[unsafe(method(init))]
        #[unsafe(method_family = init)]
        pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>;
    );
}

/// Methods declared on superclass `NSObject`.
impl UNNotificationActionIcon {
    extern_methods!(
        #[unsafe(method(new))]
        #[unsafe(method_family = new)]
        pub unsafe fn new() -> Retained<Self>;
    );
}
