//! This file has been automatically generated by `objc2`'s `header-translator`.
//! DO NOT EDIT
use core::ptr::NonNull;
use objc2::__framework_prelude::*;
use objc2_foundation::*;

use crate::*;

extern "C" {
    /// [Apple's documentation](https://developer.apple.com/documentation/usernotifications/unnotificationdefaultactionidentifier?language=objc)
    pub static UNNotificationDefaultActionIdentifier: &'static NSString;
}

extern "C" {
    /// [Apple's documentation](https://developer.apple.com/documentation/usernotifications/unnotificationdismissactionidentifier?language=objc)
    pub static UNNotificationDismissActionIdentifier: &'static NSString;
}

extern_class!(
    /// [Apple's documentation](https://developer.apple.com/documentation/usernotifications/unnotificationresponse?language=objc)
    #[unsafe(super(NSObject))]
    #[derive(Debug, PartialEq, Eq, Hash)]
    pub struct UNNotificationResponse;
);

extern_conformance!(
    unsafe impl NSCoding for UNNotificationResponse {}
);

extern_conformance!(
    unsafe impl NSCopying for UNNotificationResponse {}
);

unsafe impl CopyingHelper for UNNotificationResponse {
    type Result = Self;
}

extern_conformance!(
    unsafe impl NSObjectProtocol for UNNotificationResponse {}
);

extern_conformance!(
    unsafe impl NSSecureCoding for UNNotificationResponse {}
);

impl UNNotificationResponse {
    extern_methods!(
        #[cfg(feature = "UNNotification")]
        #[unsafe(method(notification))]
        #[unsafe(method_family = none)]
        pub fn notification(&self) -> Retained<UNNotification>;

        #[unsafe(method(actionIdentifier))]
        #[unsafe(method_family = none)]
        pub fn actionIdentifier(&self) -> Retained<NSString>;

        #[unsafe(method(init))]
        #[unsafe(method_family = init)]
        pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>;
    );
}

/// Methods declared on superclass `NSObject`.
impl UNNotificationResponse {
    extern_methods!(
        #[unsafe(method(new))]
        #[unsafe(method_family = new)]
        pub unsafe fn new() -> Retained<Self>;
    );
}

extern_class!(
    /// [Apple's documentation](https://developer.apple.com/documentation/usernotifications/untextinputnotificationresponse?language=objc)
    #[unsafe(super(UNNotificationResponse, NSObject))]
    #[derive(Debug, PartialEq, Eq, Hash)]
    pub struct UNTextInputNotificationResponse;
);

extern_conformance!(
    unsafe impl NSCoding for UNTextInputNotificationResponse {}
);

extern_conformance!(
    unsafe impl NSCopying for UNTextInputNotificationResponse {}
);

unsafe impl CopyingHelper for UNTextInputNotificationResponse {
    type Result = Self;
}

extern_conformance!(
    unsafe impl NSObjectProtocol for UNTextInputNotificationResponse {}
);

extern_conformance!(
    unsafe impl NSSecureCoding for UNTextInputNotificationResponse {}
);

impl UNTextInputNotificationResponse {
    extern_methods!(
        #[unsafe(method(userText))]
        #[unsafe(method_family = none)]
        pub fn userText(&self) -> Retained<NSString>;
    );
}

/// Methods declared on superclass `UNNotificationResponse`.
impl UNTextInputNotificationResponse {
    extern_methods!(
        #[unsafe(method(init))]
        #[unsafe(method_family = init)]
        pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>;
    );
}

/// Methods declared on superclass `NSObject`.
impl UNTextInputNotificationResponse {
    extern_methods!(
        #[unsafe(method(new))]
        #[unsafe(method_family = new)]
        pub unsafe fn new() -> Retained<Self>;
    );
}
